Simexplorer-si-commits
Threads by month
- ----- 2026 -----
- June
- May
- April
- March
- February
- January
- ----- 2025 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2024 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2023 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2022 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2021 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2020 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2019 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2018 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2017 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2016 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2015 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2014 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2013 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2012 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2011 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2010 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2009 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2008 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2007 -----
- December
- November
- October
March 2008
- 2 participants
- 198 discussions
r1373 - trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui
by tchemit@users.labs.libre-entreprise.org 17 Mar '08
by tchemit@users.labs.libre-entreprise.org 17 Mar '08
17 Mar '08
Author: tchemit
Date: 2008-03-17 18:12:28 +0000 (Mon, 17 Mar 2008)
New Revision: 1373
Modified:
trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerUI.jaxx
Log:
hide menu debug when no debugMode :)
Modified: trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerUI.jaxx
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerUI.jaxx 2008-03-17 18:12:04 UTC (rev 1372)
+++ trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerUI.jaxx 2008-03-17 18:12:28 UTC (rev 1373)
@@ -37,7 +37,7 @@
<JMenuItem id="site"/>
<JMenuItem id="about"/>
</JMenu>
- <JMenu text='simexplorer.debug.menu'>
+ <JMenu id="debug" text='simexplorer.debug.menu'>
<JMenuItem id="generateData"/>
</JMenu>
</JMenuBar>
1
0
r1372 - in trunk/simexplorer-is/simexplorer-is-swing: . src/java/fr/cemagref/simexplorer/is/ui/swing src/java/fr/cemagref/simexplorer/is/ui/swing/actions src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab src/java/fr/cemagref/simexplorer/is/ui/swing/ui
by tchemit@users.labs.libre-entreprise.org 17 Mar '08
by tchemit@users.labs.libre-entreprise.org 17 Mar '08
17 Mar '08
Author: tchemit
Date: 2008-03-17 18:12:04 +0000 (Mon, 17 Mar 2008)
New Revision: 1372
Modified:
trunk/simexplorer-is/simexplorer-is-swing/pom.xml
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerActionManager.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/SiteAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerMainUI.java
Log:
change getConfig to getMainConfig
Modified: trunk/simexplorer-is/simexplorer-is-swing/pom.xml
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/pom.xml 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/pom.xml 2008-03-17 18:12:04 UTC (rev 1372)
@@ -56,25 +56,27 @@
<treateDefaultEntry>false</treateDefaultEntry>
<entries>
<entry>
- <basedir>${maven.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/actions</basedir>
+ <basedir>${maven.src.dir}/java</basedir>
+ <!--basedir>${maven.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/actions</basedir-->
<includes>
- <param>**\/*Action.java</param>
+ <param>fr\/cemagref\/simexplorer\/is\/ui\/swing\/actions\/**\/*Action.java</param>
</includes>
<excludes>
- <param>**\/*AbstractAction.java</param>
+ <param>fr\/cemagref\/simexplorer\/is\/ui\/swing\/actions\/**\/*AbstractAction.java</param>
</excludes>
</entry>
<entry>
- <basedir>${maven.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/ui</basedir>
+ <basedir>${maven.src.dir}/java</basedir>
<includes>
- <param>SimExplorerTab.java</param>
+ <param>fr\/cemagref\/simexplorer\/is\/ui\/swing\/ui\/SimExplorerTab.java</param>
</includes>
</entry>
</entries>
</configuration>
</execution>
<execution>
- <phase>compile</phase>
+ <!--phase>compile</phase-->
+ <phase>process-classes</phase>
<id>java</id>
<goals>
<goal>parserJava</goal>
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -60,9 +60,10 @@
public static void init(String... args) {
try {
- // init context, parser and configs
+ // instanciate context, parser and configs
context = new SimExplorerContext();
+ // init context
context.init(args);
} catch (IOException e) {
@@ -88,7 +89,7 @@
// init ui
SimExplorerMainUI mainUI = SimExplorerMainUI.getUI();
- SimExplorerConfigMain conf = getContext().getConfig();
+ SimExplorerConfigMain conf = getContext().getMainConfig();
if (conf.isShowLocalTab()) {
// show local tab
@@ -158,7 +159,7 @@
}
public void initI18n() {
- I18n.initISO88591(getContext().getConfig().getUserLocale());
+ I18n.initISO88591(getContext().getMainConfig().getUserLocale());
}
protected SimExplorer() {
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerActionManager.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerActionManager.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerActionManager.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -26,6 +26,7 @@
import jaxx.runtime.builder.SimpleActionFactoryImpl;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
+import org.codelutin.i18n.I18nable;
import javax.swing.AbstractAction;
import javax.swing.AbstractButton;
@@ -42,6 +43,7 @@
* @author tony
* @see fr.cemagref.simexplorer.is.ui.swing.actions.util.SimExplorerAbstractAction
*/
+ at I18nable
public class SimExplorerActionManager {
private static final Log log = LogFactory.getLog(SimExplorerActionManager.class);
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -85,7 +85,7 @@
}
public void initI18n() {
- I18n.initISO88591(getConfig().getUserLocale());
+ I18n.initISO88591(getMainConfig().getUserLocale());
}
@@ -93,7 +93,7 @@
// init local service
getLocalStorageService();
- if (getConfig().isAutoConnect()) {
+ if (getMainConfig().isAutoConnect()) {
getRemoteStorageService();
}
}
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -61,7 +61,7 @@
public ConfigUI getUi() {
if (ui == null) {
- ui = new ConfigUI().init(getContext(),getContext().getConfig(),getContext().getLocalConfig(),getContext().getRemoteConfig());
+ ui = new ConfigUI().init(getContext(),getContext().getMainConfig(),getContext().getLocalConfig(),getContext().getRemoteConfig());
}
return ui;
}
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/SiteAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/SiteAction.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/SiteAction.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -54,7 +54,7 @@
if (!super.beforeAction(e)) {
return false;
}
- siteUrl = getContext().getConfig().getSiteURL();
+ siteUrl = getContext().getMainConfig().getSiteURL();
return siteUrl != null;
}
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -88,7 +88,7 @@
// suppression de l'historique
SimExplorerActionManager.fireAction("historyReset", e.getSource());
- getContext().getConfig().setUserLocale(locale);
+ getContext().getMainConfig().setUserLocale(locale);
// on doit initialiser la nouvelle locale avant de decharger les ui
// au cas ou un appel à une ui surviendrait et dans quel cas la locale
// serait toujours sur l'ancienne valeur ...
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -74,7 +74,7 @@
// no selection at first load
synch(remote, null, null);
// set default sizor from config
- setWidth(remote ? context.getConfig().getRemoteSizor() : context.getConfig().getLocalSizor());
+ setWidth(remote ? context.getMainConfig().getRemoteSizor() : context.getMainConfig().getLocalSizor());
}
public void setSelectedIndex(int selectedIndex) {
@@ -267,7 +267,7 @@
*
* @author tony
*/
- public static class PaginationModel {
+ public static class PaginationModel implements Serializable{
/** default size of a page */
protected SimplePaginationEnum defaultWidth;
@@ -280,6 +280,7 @@
/** size of a page */
protected SimplePaginationEnum width;
+ private static final long serialVersionUID = -1997321819766676403L;
public PaginationModel(SimplePaginationEnum defaultWidth) {
this.defaultWidth = defaultWidth;
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerMainUI.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerMainUI.java 2008-03-17 17:45:56 UTC (rev 1371)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/ui/SimExplorerMainUI.java 2008-03-17 18:12:04 UTC (rev 1372)
@@ -120,6 +120,10 @@
// repaint i18n actions
refreshI18nActions(context);
+ if (!context.getMainConfig().isDebugMode()) {
+ getDebug().setVisible(false);
+ }
+
UpdateButton(getHistoryReset(), false);
}
@@ -131,7 +135,7 @@
*/
public void refreshI18nActions(SimExplorerContext context) {
- LocaleEnum locale = context.getConfig().getUserLocale();
+ LocaleEnum locale = context.getMainConfig().getUserLocale();
//CountryEnum country = context.getConfig().getUserCountry();
String[] actions = SimExplorerActionManager.getFactory().getActionNames();
for (String actionName : actions) {
1
0
r1371 - in trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web: pages pages/security services tools
by glandais@users.labs.libre-entreprise.org 17 Mar '08
by glandais@users.labs.libre-entreprise.org 17 Mar '08
17 Mar '08
Author: glandais
Date: 2008-03-17 17:45:56 +0000 (Mon, 17 Mar 2008)
New Revision: 1371
Modified:
trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/Login.java
trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/security/ProtectedPage.java
trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/services/SimExplorerState.java
trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/tools/WebEntityVisitor.java
Log:
Redirect after login
Modified: trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/Login.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/Login.java 2008-03-17 17:45:04 UTC (rev 1370)
+++ trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/Login.java 2008-03-17 17:45:56 UTC (rev 1371)
@@ -20,6 +20,7 @@
import java.io.IOException;
import java.util.Arrays;
+import org.apache.tapestry.ComponentResources;
import org.apache.tapestry.annotations.ApplicationState;
import org.apache.tapestry.annotations.Component;
import org.apache.tapestry.annotations.InjectPage;
@@ -27,7 +28,6 @@
import org.apache.tapestry.corelib.components.Form;
import org.apache.tapestry.ioc.Messages;
import org.apache.tapestry.ioc.annotations.Inject;
-import org.apache.tapestry.services.RequestGlobals;
import fr.cemagref.simexplorer.is.exceptions.SimExplorerException;
import fr.cemagref.simexplorer.is.security.entities.User;
@@ -61,10 +61,6 @@
@ApplicationState
private SimExplorerState applicationState;
- /** The request globals. */
- @Inject
- private RequestGlobals requestGlobals;
-
/** The messages. */
@Inject
private Messages messages;
@@ -73,13 +69,17 @@
@Component
private Form formLogin;
+ /** The resources. */
+ @Inject
+ private ComponentResources resources;
+
/**
* On success.
*
* @return the object
*
* @throws SimExplorerException the sim explorer exception
- * @throws IOException
+ * @throws IOException
*/
public Object onSuccessFromFormLogin() throws SimExplorerException, IOException {
// on hache directement le password pour ne pas le transmettre en clair
@@ -91,18 +91,17 @@
String token = RemoteSecurityService.getAuthentificationService().loginUser(user, pass);
if (token != null && !token.equals("")) {
-
+
User loggedUser = RemoteSecurityService.getAuthentificationService().getLoggedUser(token);
applicationState.setToken(token);
applicationState.setUser(loggedUser);
-
- String fromURL = applicationState.getRequestedURL();
- if (fromURL == null) {
+
+ String fromPage = applicationState.getPageName();
+ if (fromPage == null) {
return elementList;
}
- //return fromURL.substring(1);
- requestGlobals.getResponse().sendRedirect(fromURL);
+ return resources.createPageLink(applicationState.getPageName(), true, applicationState.getPageContext());
}
formLogin.recordError(messages.get("simexplorer.ui.web.login.invalid"));
return this;
Modified: trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/security/ProtectedPage.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/security/ProtectedPage.java 2008-03-17 17:45:04 UTC (rev 1370)
+++ trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/pages/security/ProtectedPage.java 2008-03-17 17:45:56 UTC (rev 1371)
@@ -22,7 +22,6 @@
import org.apache.tapestry.annotations.Persist;
import org.apache.tapestry.ioc.Messages;
import org.apache.tapestry.ioc.annotations.Inject;
-import org.apache.tapestry.services.RequestGlobals;
import org.codelutin.i18n.I18n;
import fr.cemagref.simexplorer.is.exceptions.SimExplorerException;
@@ -40,10 +39,6 @@
@ApplicationState
private SimExplorerState applicationState;
- /** The request globals. */
- @Inject
- private RequestGlobals requestGlobals;
-
/** The user. */
@Persist
private User user;
@@ -75,11 +70,11 @@
*
* @throws SimExplorerException the sim explorer exception
*/
- Object onActivate() throws SimExplorerException {
+ Object onActivate(Object... pageContext) throws SimExplorerException {
getUserRights();
if (!userLogged) {
- String fromURL = requestGlobals.getRequest().getPath();
- applicationState.setRequestedURL(fromURL);
+ applicationState.setPageName(resources.getPageName());
+ applicationState.setPageContext(pageContext);
return "Login";
}
if (!hasAccessToPage())
Modified: trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/services/SimExplorerState.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/services/SimExplorerState.java 2008-03-17 17:45:04 UTC (rev 1370)
+++ trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/services/SimExplorerState.java 2008-03-17 17:45:56 UTC (rev 1371)
@@ -30,8 +30,11 @@
/** The user. */
private User user;
- /** The requested url. */
- private String requestedURL;
+ /** The page name. */
+ private String pageName;
+
+ /** The page context. */
+ private Object[] pageContext;
/**
* Instantiates a new sim explorer state.
@@ -40,7 +43,8 @@
super();
token = null;
user = null;
- requestedURL = null;
+ pageName = null;
+ pageContext = null;
}
/**
@@ -80,21 +84,40 @@
}
/**
- * Gets the requested url.
+ * Gets the page name.
*
- * @return the requested url
+ * @return the page name
*/
- public String getRequestedURL() {
- return requestedURL;
+ public String getPageName() {
+ return pageName;
}
/**
- * Sets the requested url.
+ * Sets the page name.
*
- * @param requestedURL the new requested url
+ * @param pageName the new page name
*/
- public void setRequestedURL(String requestedURL) {
- this.requestedURL = requestedURL;
+ public void setPageName(String pageName) {
+ this.pageName = pageName;
}
+ /**
+ * Gets the page context.
+ *
+ * @return the page context
+ */
+ public Object[] getPageContext() {
+ return pageContext;
+ }
+
+ /**
+ * Sets the page context.
+ *
+ * @param pageContext the new page context
+ */
+ public void setPageContext(Object[] pageContext) {
+ this.pageContext = pageContext;
+ }
+
+
}
Modified: trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/tools/WebEntityVisitor.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/tools/WebEntityVisitor.java 2008-03-17 17:45:04 UTC (rev 1370)
+++ trunk/simexplorer-is/simexplorer-is-web/src/java/fr/cemagref/simexplorer/is/ui/web/tools/WebEntityVisitor.java 2008-03-17 17:45:56 UTC (rev 1371)
@@ -28,7 +28,6 @@
import fr.cemagref.simexplorer.is.entities.Composite;
import fr.cemagref.simexplorer.is.entities.Entity;
import fr.cemagref.simexplorer.is.entities.EntityHelper;
-import fr.cemagref.simexplorer.is.entities.EntityTypeEnum;
import fr.cemagref.simexplorer.is.entities.EntityVisitorTreeNode;
import fr.cemagref.simexplorer.is.entities.SimExplorerPage;
import fr.cemagref.simexplorer.is.entities.EntityHelper.Action;
1
0
r1370 - in trunk/simexplorer-is: simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/attachment simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite simexplorer-is-service/src/java/fr/cemagref/simexplorer/is/service simexplorer-is-service/src/test/fr/cemagref/simexplorer/is/service simexplorer-is-service/src/test/properties simexplorer-is-storage/src/java/fr/cemagref/simex
by glandais@users.labs.libre-entreprise.org 17 Mar '08
by glandais@users.labs.libre-entreprise.org 17 Mar '08
17 Mar '08
Author: glandais
Date: 2008-03-17 17:45:04 +0000 (Mon, 17 Mar 2008)
New Revision: 1370
Added:
trunk/simexplorer-is/simexplorer-is-service/src/test/properties/configlocal.properties
trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StreamInfo.java
Removed:
trunk/simexplorer-is/simexplorer-is-service/src/test/properties/config.properties
Modified:
trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/Leaf.java
trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/attachment/Attachment.java
trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/Attachments.java
trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/SimpleComposite.java
trunk/simexplorer-is/simexplorer-is-service/src/java/fr/cemagref/simexplorer/is/service/StorageServiceCommon.java
trunk/simexplorer-is/simexplorer-is-service/src/test/fr/cemagref/simexplorer/is/service/StorageServiceVersionsLocalTestCase.java
trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/AttachmentHandler.java
trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/FileSystemAttachmentHandler.java
trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngine.java
trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngineImpl.java
Log:
Data size added
Modified: trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/Leaf.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/Leaf.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/Leaf.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -36,6 +36,7 @@
/* (non-Javadoc)
* @see fr.cemagref.simexplorer.is.entities.EntityVisitable#accept(fr.cemagref.simexplorer.is.entities.EntityVisitor)
*/
+ @Override
public void accept(EntityVisitor visitor) {
visitor.visitLeaf(this);
}
Modified: trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/attachment/Attachment.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/attachment/Attachment.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/attachment/Attachment.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -23,6 +23,7 @@
import java.util.List;
import org.apache.commons.lang.StringUtils;
+import org.codelutin.util.StringUtil;
import fr.cemagref.simexplorer.is.entities.Leaf;
@@ -33,8 +34,8 @@
*/
public class Attachment extends Leaf {
- /** Serial version ID. */
- private static final long serialVersionUID = 5467615366054227592L;
+ /** The Constant serialVersionUID. */
+ private static final long serialVersionUID = -7574882159899851556L;
/** Filename. */
private String fileName;
@@ -45,6 +46,9 @@
/** Data hash. */
private String dataHash;
+ /** The data size. */
+ private long dataSize;
+
/**
* Gets the file name.
*
@@ -100,6 +104,24 @@
}
/**
+ * Gets the data size.
+ *
+ * @return the data size
+ */
+ public long getDataSize() {
+ return dataSize;
+ }
+
+ /**
+ * Sets the data size.
+ *
+ * @param dataSize the new data size
+ */
+ public void setDataSize(long dataSize) {
+ this.dataSize = dataSize;
+ }
+
+ /**
* Gets the unique id.
*
* @return the unique id
@@ -178,17 +200,23 @@
if (getContentType() != null) {
sb.append(" - ").append(_(getContentType().getDescription()));
}
+ sb.append(" (").append(StringUtil.convertMemory(getDataSize())).append(")");
return sb.toString();
}
+ /* (non-Javadoc)
+ * @see fr.cemagref.simexplorer.is.entities.Entity#getRow()
+ */
@Override
public List<String> getRow() {
List<String> row = new ArrayList<String>();
- row.add("");
row.add(getFileName());
if (getContentType() != null) {
row.add(_(getContentType().getDescription()));
+ } else {
+ row.add("");
}
+ row.add(StringUtil.convertMemory(getDataSize()));
return row;
}
Modified: trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/Attachments.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/Attachments.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/Attachments.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -21,6 +21,8 @@
import java.util.List;
+import org.codelutin.util.StringUtil;
+
import fr.cemagref.simexplorer.is.entities.EntityVisitor;
import fr.cemagref.simexplorer.is.entities.attachment.Attachment;
@@ -40,9 +42,24 @@
@Override
public List<String> getRow() {
List<String> row = super.getRow();
- row.add(_("simexplorer.common.attachment.filename"));
+ row.set(0, row.get(0) + " - " + _("simexplorer.common.attachment.filename"));
row.add(_("simexplorer.common.attachment.datatype"));
+ row.add(StringUtil.convertMemory(getTotalSize()));
return row;
}
-}
+ /**
+ * Gets the total size.
+ *
+ * @return the total size
+ */
+ public long getTotalSize() {
+ List<Attachment> children = getInnerList();
+ long total = 0;
+ for (Attachment attachment : children) {
+ total += attachment.getDataSize();
+ }
+ return total;
+ }
+
+}
\ No newline at end of file
Modified: trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/SimpleComposite.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/SimpleComposite.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-entities/src/java/fr/cemagref/simexplorer/is/entities/composite/SimpleComposite.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -151,6 +151,15 @@
row.add(toString());
return row;
}
+
+ /**
+ * Gets the inner list.
+ *
+ * @return the inner list
+ */
+ public List<E> getInnerList() {
+ return elements;
+ }
/**
* Delegate List methods.
Modified: trunk/simexplorer-is/simexplorer-is-service/src/java/fr/cemagref/simexplorer/is/service/StorageServiceCommon.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-service/src/java/fr/cemagref/simexplorer/is/service/StorageServiceCommon.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-service/src/java/fr/cemagref/simexplorer/is/service/StorageServiceCommon.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -37,8 +37,6 @@
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
-import org.codelutin.util.MD5;
-import org.codelutin.util.MD5InputStream;
import org.codelutin.util.ZipStreamEncoder;
import com.healthmarketscience.rmiio.SerializableInputStream;
@@ -57,6 +55,7 @@
import fr.cemagref.simexplorer.is.storage.SortColumn;
import fr.cemagref.simexplorer.is.storage.SortOrder;
import fr.cemagref.simexplorer.is.storage.engine.StorageEngine;
+import fr.cemagref.simexplorer.is.storage.engine.StreamInfo;
/**
* The Class StorageServiceCommon.
@@ -75,9 +74,6 @@
/** The Constant log. */
private static final Log log = LogFactory.getLog(StorageServiceCommon.class);
- /** The xml attachment. */
- protected Attachment xmlAttachment = null;
-
/**
* Gets the storage engine.
*
@@ -262,27 +258,21 @@
while (entry != null) {
if (!entry.isDirectory()) {
String entryName = entry.getName();
+ StreamInfo streamInfo = getStorageEngine().storeTempData(zis);
if (entryName.equals(FILE_XML)) {
- xmlFile = getStorageEngine().storeTempData(zis);
+ xmlFile = streamInfo.getUuid();
} else {
if (entryName.startsWith(FILE_DATA_PREFIX)) {
String fileName = entryName.replace(FILE_DATA_PREFIX + FOLDER_SEPARATOR, "");
-
- String zipMD5 = Attachment.getHashFromUniqueId(fileName);
fileName = Attachment.getFileNameFromUniqueId(fileName);
-
- MD5InputStream md5Stream = new MD5InputStream(zis);
- String idFile = getStorageEngine().storeTempData(md5Stream);
-
- String localMD5 = MD5.asHex(md5Stream.hash());
-
- if (!localMD5.equals(zipMD5)) {
+ String idFile = streamInfo.getUuid();
+ String zipMD5 = Attachment.getHashFromUniqueId(fileName);
+ if (!streamInfo.getHash().equals(zipMD5)) {
throw new SimExplorerBusinessException(_("simexplorer.service.invalidhash"));
-
}
Attachment attachment = new Attachment();
attachment.setFileName(fileName);
- attachment.setDataHash(localMD5);
+ attachment.setDataHash(zipMD5);
attachments.put(attachment, idFile);
}
}
@@ -319,10 +309,14 @@
public LoggableElement saveElement(String token, SerializableInputStream xmlFile,
Map<Attachment, SerializableInputStream> attachments) throws SimExplorerException {
// Store temporary data
- String idxml = getStorageEngine().storeTempData(xmlFile);
+ String idxml = getStorageEngine().storeTempData(xmlFile).getUuid();
Map<Attachment, String> idsattachment = new HashMap<Attachment, String>();
for (Map.Entry<Attachment, SerializableInputStream> entry : attachments.entrySet()) {
- String idattachment = getStorageEngine().storeTempData(entry.getValue());
+ StreamInfo streamInfo = getStorageEngine().storeTempData(entry.getValue());
+ String idattachment = streamInfo.getUuid();
+ if (!streamInfo.getHash().equals(entry.getKey().getDataHash())) {
+ throw new SimExplorerBusinessException(_("simexplorer.service.invalidhash"));
+ }
idsattachment.put(entry.getKey(), idattachment);
}
InputStream xmlData = getStorageEngine().retrieveTempData(idxml);
@@ -524,7 +518,8 @@
*
* @throws SimExplorerException the sim explorer exception
*/
- private void getDeletableChildren(String token, String uuid, String version, Set<MetaData> set) throws SimExplorerException {
+ private void getDeletableChildren(String token, String uuid, String version, Set<MetaData> set)
+ throws SimExplorerException {
// this item is an orphan only if it has one parent maximum
MetaData[] metadatasUsedBy = getMetadatasUsedBy(token, uuid, version);
if (metadatasUsedBy.length <= 1) {
@@ -674,11 +669,9 @@
* @return the xML attachment
*/
private Attachment getXMLAttachment() {
- if (xmlAttachment == null) {
- xmlAttachment = new Attachment();
- xmlAttachment.setDataHash("");
- xmlAttachment.setFileName("entity.xml");
- }
+ Attachment xmlAttachment = new Attachment();
+ xmlAttachment.setFileName("entity.xml");
+ xmlAttachment.setDataHash("");
return xmlAttachment;
}
@@ -760,10 +753,9 @@
// Compute element hash
metaData.setHash(Long.toString(loggableElement.hashCode()));
}
-
+
/**
- * Save all LE under element
- * Only first level LE are saved
+ * Save all LE under element Only first level LE are saved
*
* @param token the token
* @param element the element
@@ -775,7 +767,7 @@
throws SimExplorerException {
List<Entity> children = element.getChildren();
for (Entity child : children) {
- if (child instanceof LoggableElement) {
+ if (child instanceof LoggableElement) {
LoggableElement leChild = (LoggableElement) child;
LoggableElement childElement = saveElement(token, leChild, idsattachment);
// TODO check
Modified: trunk/simexplorer-is/simexplorer-is-service/src/test/fr/cemagref/simexplorer/is/service/StorageServiceVersionsLocalTestCase.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-service/src/test/fr/cemagref/simexplorer/is/service/StorageServiceVersionsLocalTestCase.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-service/src/test/fr/cemagref/simexplorer/is/service/StorageServiceVersionsLocalTestCase.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -29,7 +29,7 @@
*/
@Override
protected void buildStorageService() {
- storageService = new StorageServiceClient();
+ storageService = new StorageServiceClient("/properties/configlocal.properties", null);
}
/* (non-Javadoc)
Deleted: trunk/simexplorer-is/simexplorer-is-service/src/test/properties/config.properties
===================================================================
--- trunk/simexplorer-is/simexplorer-is-service/src/test/properties/config.properties 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-service/src/test/properties/config.properties 2008-03-17 17:45:04 UTC (rev 1370)
@@ -1,4 +0,0 @@
-simexplorer.db=/var/local/simexplorer/local-db
-simexplorer.data=/var/local/simexplorer/local-data
-simexplorer.optimizeperiod=3600
-simexplorer.adminmail=landais at codelutin.com
Copied: trunk/simexplorer-is/simexplorer-is-service/src/test/properties/configlocal.properties (from rev 1369, trunk/simexplorer-is/simexplorer-is-service/src/test/properties/config.properties)
===================================================================
--- trunk/simexplorer-is/simexplorer-is-service/src/test/properties/configlocal.properties (rev 0)
+++ trunk/simexplorer-is/simexplorer-is-service/src/test/properties/configlocal.properties 2008-03-17 17:45:04 UTC (rev 1370)
@@ -0,0 +1,4 @@
+simexplorer.db=/var/local/simexplorer/local-db
+simexplorer.data=/var/local/simexplorer/local-data
+simexplorer.optimizeperiod=3600
+simexplorer.adminmail=landais at codelutin.com
Modified: trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/AttachmentHandler.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/AttachmentHandler.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/AttachmentHandler.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -53,20 +53,8 @@
* @throws SimExplorerException the sim explorer storage exception
*/
public abstract InputStream retrieveData(MetaData entity, Attachment attachment) throws SimExplorerException;
-
+
/**
- * Retrieve MD5.
- *
- * @param entity the entity
- * @param attachment the attachment
- *
- * @return the string
- *
- * @throws SimExplorerException the sim explorer storage exception
- */
- public abstract String retrieveMD5Data(MetaData entity, Attachment attachment) throws SimExplorerException;
-
- /**
* Delete content.
*
* @param entity DataEntity related to content
Modified: trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/FileSystemAttachmentHandler.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/FileSystemAttachmentHandler.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/attachment/FileSystemAttachmentHandler.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -28,6 +28,7 @@
import java.io.OutputStream;
import org.codelutin.util.MD5;
+import org.codelutin.util.MD5InputStream;
import fr.cemagref.simexplorer.is.entities.attachment.Attachment;
import fr.cemagref.simexplorer.is.entities.metadata.MetaData;
@@ -104,23 +105,9 @@
throw new SimExplorerTechnicalException(e);
}
return fis;
- }
+ }
/* (non-Javadoc)
- * @see fr.cemagref.simexplorer.is.storage.attachment.AttachmentHandler#retrieveMD5Data(fr.cemagref.simexplorer.is.entities.metadata.MetaData, java.lang.String)
- */
- @Override
- public String retrieveMD5Data(MetaData entity, Attachment attachment) throws SimExplorerException {
- String md5;
- try {
- md5 = MD5.asHex(MD5.getHash(getFile(entity, attachment, false)));
- } catch (Exception e) {
- throw new SimExplorerTechnicalException(e);
- }
- return md5;
- }
-
- /* (non-Javadoc)
* @see fr.cemagref.simexplorer.is.storage.attachment.AttachmentHandler#storeData(fr.cemagref.simexplorer.is.entities.metadata.MetaData, java.lang.String, java.io.InputStream)
*/
@Override
@@ -135,16 +122,20 @@
// Buffer copy stream to stream
BufferedInputStream bin = new BufferedInputStream(is);
+ MD5InputStream md5is = new MD5InputStream(bin);
bout = new BufferedOutputStream(fos);
while (true) {
- int datum = bin.read();
+ int datum = md5is.read();
if (datum == -1)
break;
bout.write(datum);
}
bout.flush();
+
+ attachment.setDataHash(MD5.asHex(md5is.hash()));
+ attachment.setDataSize(md5is.getStreamLength());
} catch (FileNotFoundException e) {
throw new SimExplorerTechnicalException(e);
Modified: trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngine.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngine.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngine.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -246,7 +246,8 @@
*
* @throws SimExplorerException the sim explorer storage exception
*/
- public abstract int findFullTextCount(String token, String query, SearchColumn searchColumn, boolean onlyLatest) throws SimExplorerException;
+ public abstract int findFullTextCount(String token, String query, SearchColumn searchColumn, boolean onlyLatest)
+ throws SimExplorerException;
/**
* Retrieve list of items corresponding to query.
@@ -264,8 +265,8 @@
*
* @throws SimExplorerException the sim explorer storage exception
*/
- public abstract MetaData[] findFullText(String token, String query, SearchColumn searchColumn, boolean onlyLatest, int indexStart, int count,
- SortColumn sortColumn, SortOrder sortOrder) throws SimExplorerException;
+ public abstract MetaData[] findFullText(String token, String query, SearchColumn searchColumn, boolean onlyLatest,
+ int indexStart, int count, SortColumn sortColumn, SortOrder sortOrder) throws SimExplorerException;
/**
* Retrieve list of items of type wanted.
@@ -319,19 +320,9 @@
*
* @throws SimExplorerException the sim explorer storage exception
*/
- public abstract String storeTempData(InputStream stream) throws SimExplorerException;
+ public abstract StreamInfo storeTempData(InputStream stream) throws SimExplorerException;
/**
- * Store temporary data, for stream duplication.
- *
- * @param stream Stream to store
- * @param id the id
- *
- * @throws SimExplorerException the sim explorer storage exception
- */
- public abstract void storeTempData(String id, InputStream stream) throws SimExplorerException;
-
- /**
* Retrieve temporary data.
*
* @param id Id associated
@@ -343,17 +334,6 @@
public abstract InputStream retrieveTempData(String id) throws SimExplorerException;
/**
- * Retrieve MD5 temp data.
- *
- * @param id the id
- *
- * @return the string
- *
- * @throws SimExplorerException the sim explorer storage exception
- */
- public abstract String retrieveMD5TempData(String id) throws SimExplorerException;
-
- /**
* Delete temporary data.
*
* @param id the id
Modified: trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngineImpl.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngineImpl.java 2008-03-16 21:10:15 UTC (rev 1369)
+++ trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StorageEngineImpl.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -55,11 +55,10 @@
/** Storage. */
protected AttachmentHandler attachmentHandler;
- /** Metadata handling temporary data. */
- private MetaData mdTmp;
-
/** The opened. */
private boolean opened = false;
+
+ private static final String uuidTmpData = UUID.randomUUID().toString();
/**
* Convert list.
@@ -94,10 +93,15 @@
database = new LuceneDatabase();
// Storage
attachmentHandler = new FileSystemAttachmentHandler();
+
+ }
+
+ private MetaData getTmpMetaData() {
// Storing tmp data
- mdTmp = new MetaData();
- mdTmp.setUuid(UUID.randomUUID().toString());
+ MetaData mdTmp = new MetaData();
+ mdTmp.setUuid(uuidTmpData);
mdTmp.setVersion("0");
+ return mdTmp;
}
/* (non-Javadoc)
@@ -341,44 +345,32 @@
/* (non-Javadoc)
* @see fr.cemagref.simexplorer.is.storage.engine.StorageEngine#storeTempData(java.io.InputStream)
*/
- public String storeTempData(InputStream stream) throws SimExplorerException {
- String id = UUID.randomUUID().toString();
- storeTempData(id, stream);
- return id;
+ public StreamInfo storeTempData(InputStream stream) throws SimExplorerException {
+ String id = UUID.randomUUID().toString();
+ StreamInfo streamInfo = new StreamInfo();
+ MetaData tmpMetaData = getTmpMetaData();
+ Attachment tmpAttachment = getTmpAttachment(id);
+ attachmentHandler.storeData(tmpMetaData, tmpAttachment, stream);
+ streamInfo.setUuid(id);
+ streamInfo.setHash(tmpAttachment.getDataHash());
+ streamInfo.setLength(tmpAttachment.getDataSize());
+ return streamInfo;
}
/* (non-Javadoc)
- * @see fr.cemagref.simexplorer.is.storage.engine.StorageEngine#storeTempData(java.lang.String, java.io.InputStream)
- */
- @Override
- public void storeTempData(String id, InputStream stream) throws SimExplorerException {
- attachmentHandler.storeData(mdTmp, getTmpAttachment(id), stream);
- }
-
- /* (non-Javadoc)
* @see fr.cemagref.simexplorer.is.storage.engine.StorageEngine#retrieveTempData(java.lang.String)
*/
public InputStream retrieveTempData(String id) throws SimExplorerException {
InputStream is;
- is = attachmentHandler.retrieveData(mdTmp, getTmpAttachment(id));
+ is = attachmentHandler.retrieveData(getTmpMetaData(), getTmpAttachment(id));
return is;
}
/* (non-Javadoc)
- * @see fr.cemagref.simexplorer.is.storage.engine.StorageEngine#retrieveMD5TempData(java.lang.String)
- */
- @Override
- public String retrieveMD5TempData(String id) throws SimExplorerException {
- String md5;
- md5 = attachmentHandler.retrieveMD5Data(mdTmp, getTmpAttachment(id));
- return md5;
- }
-
- /* (non-Javadoc)
* @see fr.cemagref.simexplorer.is.storage.engine.StorageEngine#deleteTempData(java.lang.String)
*/
public void deleteTempData(String id) throws SimExplorerException {
- attachmentHandler.deleteData(mdTmp, getTmpAttachment(id));
+ attachmentHandler.deleteData(getTmpMetaData(), getTmpAttachment(id));
}
/* (non-Javadoc)
Added: trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StreamInfo.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StreamInfo.java (rev 0)
+++ trunk/simexplorer-is/simexplorer-is-storage/src/java/fr/cemagref/simexplorer/is/storage/engine/StreamInfo.java 2008-03-17 17:45:04 UTC (rev 1370)
@@ -0,0 +1,88 @@
+/*
+* ##% Copyright (C) 2008 Code Lutin, Gabriel Landais
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License
+* as published by the Free Software Foundation; either version 2
+* of the License, or (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* ##% */
+package fr.cemagref.simexplorer.is.storage.engine;
+
+/**
+ * The Class StreamInfo.
+ */
+public class StreamInfo {
+
+ /** The uuid. */
+ private String uuid;
+
+ /** The hash. */
+ private String hash;
+
+ /** The length. */
+ private long length;
+
+ /**
+ * Gets the uuid.
+ *
+ * @return the uuid
+ */
+ public String getUuid() {
+ return uuid;
+ }
+
+ /**
+ * Sets the uuid.
+ *
+ * @param uuid the new uuid
+ */
+ public void setUuid(String uuid) {
+ this.uuid = uuid;
+ }
+
+ /**
+ * Gets the hash.
+ *
+ * @return the hash
+ */
+ public String getHash() {
+ return hash;
+ }
+
+ /**
+ * Sets the hash.
+ *
+ * @param hash the new hash
+ */
+ public void setHash(String hash) {
+ this.hash = hash;
+ }
+
+ /**
+ * Gets the length.
+ *
+ * @return the length
+ */
+ public long getLength() {
+ return length;
+ }
+
+ /**
+ * Sets the length.
+ *
+ * @param length the new length
+ */
+ public void setLength(long length) {
+ this.length = length;
+ }
+
+}
1
0
r1369 - in trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing: . actions actions/util
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
16 Mar '08
Author: tchemit
Date: 2008-03-16 21:10:15 +0000 (Sun, 16 Mar 2008)
New Revision: 1369
Modified:
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConnectAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ResetPasswordAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java
Log:
context is now responsible of init + save configs
TODO put all config stuff in context ? instead of parser
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java 2008-03-16 14:27:12 UTC (rev 1368)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java 2008-03-16 21:10:15 UTC (rev 1369)
@@ -61,7 +61,10 @@
try {
// init context, parser and configs
- context = new SimExplorerContext(args);
+ context = new SimExplorerContext();
+
+ context.init(args);
+
} catch (IOException e) {
log.error("io error : " + e.getMessage());
e.printStackTrace();
@@ -132,7 +135,7 @@
init(args);
// launch actions required
- context.getParser().doAllActions(context);
+ context.getParser().getLastResult().doAllActions(context);
// show edit config if first launch
if (context.isFirstLaunch()) {
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java 2008-03-16 14:27:12 UTC (rev 1368)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java 2008-03-16 21:10:15 UTC (rev 1369)
@@ -35,8 +35,6 @@
import org.codelutin.i18n.I18n;
import org.codelutin.option.ParserFailedException;
-import java.io.IOException;
-
/**
* Le context de l'application, implanté en singleton.
* <p/>
@@ -180,14 +178,19 @@
/**
* restricted access constructor
*
- * @param args argumentsfor parser
* @throws java.io.IOException if pb while saing configuration
* @throws ParserFailedException if pb while parsing arguments
*/
- SimExplorerContext(String... args) throws IOException, ParserFailedException {
+ SimExplorerContext() throws Exception {
+ super();
+ }
- super(args);
+ @Override
+ public void init(String[] args) throws Exception {
+
+ super.init(args);
+
initServices();
}
@@ -199,7 +202,7 @@
localService = new MockStorageServiceImpl(false);
} else {
try {
- localService = new StorageServiceClient(getConfig().getSource().toString(), "local.");
+ localService = new StorageServiceClient(this.getSource().toString(), "local.");
} catch (Exception e) {
throw new SimExplorerRuntimeException(e);
}
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java 2008-03-16 14:27:12 UTC (rev 1368)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConfigAction.java 2008-03-16 21:10:15 UTC (rev 1369)
@@ -61,7 +61,7 @@
public ConfigUI getUi() {
if (ui == null) {
- ui = new ConfigUI().init(getContext().getConfig(),getContext().getLocalConfig(),getContext().getRemoteConfig());
+ ui = new ConfigUI().init(getContext(),getContext().getConfig(),getContext().getLocalConfig(),getContext().getRemoteConfig());
}
return ui;
}
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConnectAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConnectAction.java 2008-03-16 14:27:12 UTC (rev 1368)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ConnectAction.java 2008-03-16 21:10:15 UTC (rev 1369)
@@ -176,7 +176,7 @@
//always keep login
getContext().getRemoteConfig().setLogin(login);
//Save configuration, I don't like it, but required by client...
- getContext().getConfig().saveSafely();
+ getContext().saveSafely();
return isConnected;
}
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ResetPasswordAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ResetPasswordAction.java 2008-03-16 14:27:12 UTC (rev 1368)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ResetPasswordAction.java 2008-03-16 21:10:15 UTC (rev 1369)
@@ -49,7 +49,7 @@
public void doAction(java.awt.event.ActionEvent e) {
getContext().getRemoteConfig().setPassword(null);
- getContext().getConfig().saveSafely();
+ getContext().saveSafely();
if (getContext().isConnected()) {
// unconnect
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java 2008-03-16 14:27:12 UTC (rev 1368)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/util/ChangeLocaleAction.java 2008-03-16 21:10:15 UTC (rev 1369)
@@ -94,7 +94,7 @@
// serait toujours sur l'ancienne valeur ...
getContext().initI18n();
// save config
- getContext().getConfig().saveSafely();
+ getContext().saveSafely();
// dispose then reload main ui
SimExplorer.dispose(true);
}
1
0
r1368 - in trunk/simexplorer-is/simexplorer-is-swing-commandline: . src/resources
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
16 Mar '08
Author: tchemit
Date: 2008-03-16 14:27:12 +0000 (Sun, 16 Mar 2008)
New Revision: 1368
Modified:
trunk/simexplorer-is/simexplorer-is-swing-commandline/pom.xml
trunk/simexplorer-is/simexplorer-is-swing-commandline/src/resources/commandline.properties
Log:
simplify commandline configuration (first pass)
Modified: trunk/simexplorer-is/simexplorer-is-swing-commandline/pom.xml
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing-commandline/pom.xml 2008-03-16 12:30:52 UTC (rev 1367)
+++ trunk/simexplorer-is/simexplorer-is-swing-commandline/pom.xml 2008-03-16 14:27:12 UTC (rev 1368)
@@ -71,19 +71,7 @@
<source>${maven.src.dir}/resources/commandline.properties</source>
<out>${maven.src.dir}/java</out>
<parserPackageName>fr.cemagref.simexplorer.is.ui.swing.commandline</parserPackageName>
- <abstractConfigOptionKey>CHANGE_CONFIG_OPTION_KEY</abstractConfigOptionKey>
- <abstractConfigFileOptionKey>CHANGE_FILE_CONFIG_OPTION_KEY</abstractConfigFileOptionKey>
- <abstractConfigFilenameConfigKey>
- fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigMain.CONFIG_FILE_NAME_PROPERTY_KEY
- </abstractConfigFilenameConfigKey>
<concreteConfig>true</concreteConfig>
- <actionImplementations>
- </actionImplementations>
- <configImplementations>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigMain</value>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigLocal</value>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigRemote</value>
- </configImplementations>
</configuration>
<executions>
<execution>
Modified: trunk/simexplorer-is/simexplorer-is-swing-commandline/src/resources/commandline.properties
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing-commandline/src/resources/commandline.properties 2008-03-16 12:30:52 UTC (rev 1367)
+++ trunk/simexplorer-is/simexplorer-is-swing-commandline/src/resources/commandline.properties 2008-03-16 14:27:12 UTC (rev 1368)
@@ -2,21 +2,8 @@
### Option definitions ########################################################
###############################################################################
-###
-### common options (TODO should be in commandline project)
-###
-showConfig.option.definition=--show-config {0,1} <main|local|remote> [all|tec]
-editConfig.option.definition=--edit-config
-changeFileConfig.option.definition=--config-file <configFile:File>
-changeConfig.option.definition=--config * [main|local|remote] <key:String> <value:String>
-resetConfig.option.definition=--resetConfig
-help.option.definition=--help|-h
-ui.option.definition=--ui <value:Boolean>
+# TODO definie them
-###
-### others options TODO
-###
-
###############################################################################
### Local configuration definition ############################################
###############################################################################
1
0
r1367 - trunk/simexplorer-is/simexplorer-is-swing-jaxx
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
16 Mar '08
Author: tchemit
Date: 2008-03-16 12:30:52 +0000 (Sun, 16 Mar 2008)
New Revision: 1367
Modified:
trunk/simexplorer-is/simexplorer-is-swing-jaxx/
Log:
...
Property changes on: trunk/simexplorer-is/simexplorer-is-swing-jaxx
___________________________________________________________________
Name: svn:ignore
- target
+ target
target/*
.project
.classpath
*.iml
*.ipr
*.iws
1
0
r1366 - trunk/simexplorer-is/simexplorer-is-swing-commandline
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
16 Mar '08
Author: tchemit
Date: 2008-03-16 12:24:24 +0000 (Sun, 16 Mar 2008)
New Revision: 1366
Modified:
trunk/simexplorer-is/simexplorer-is-swing-commandline/
Log:
...
Property changes on: trunk/simexplorer-is/simexplorer-is-swing-commandline
___________________________________________________________________
Name: svn:ignore
- *.iml
.project
.classpath
target/*
+ *.iml
.project
.classpath
target
target/*
1
0
r1365 - trunk/simexplorer-is/simexplorer-is-swing-commandline
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
by tchemit@users.labs.libre-entreprise.org 16 Mar '08
16 Mar '08
Author: tchemit
Date: 2008-03-16 12:23:07 +0000 (Sun, 16 Mar 2008)
New Revision: 1365
Modified:
trunk/simexplorer-is/simexplorer-is-swing-commandline/
Log:
...
Property changes on: trunk/simexplorer-is/simexplorer-is-swing-commandline
___________________________________________________________________
Name: svn:ignore
- *.iml
.project
.classpath
target
+ *.iml
.project
.classpath
target/*
1
0
16 Mar '08
Author: tchemit
Date: 2008-03-16 11:44:47 +0000 (Sun, 16 Mar 2008)
New Revision: 1364
Added:
trunk/simexplorer-is/simexplorer-is-swing-commandline/
Removed:
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/commandline/
trunk/simexplorer-is/simexplorer-is-swing/src/resources/commandline.properties
Modified:
trunk/simexplorer-is/pom.xml
trunk/simexplorer-is/simexplorer-is-swing-commandline/src/java/
trunk/simexplorer-is/simexplorer-is-swing-jaxx/pom.xml
trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/JListTab.jaxx
trunk/simexplorer-is/simexplorer-is-swing/dev.sh
trunk/simexplorer-is/simexplorer-is-swing/pom.xml
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ChangeSizorAction.java
trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java
trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-en_GB.properties
trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-fr_FR.properties
Log:
merge branche with trunk : split du module swing-commandline
Modified: trunk/simexplorer-is/pom.xml
===================================================================
--- trunk/simexplorer-is/pom.xml 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/pom.xml 2008-03-16 11:44:47 UTC (rev 1364)
@@ -95,14 +95,14 @@
http://lutinbuilder.labs.libre-entreprise.org/maven2
</url>
</pluginRepository>
- <pluginRepository>
+ <!--pluginRepository>
<id>evolvis-release-repository</id>
<name>evolvis.org release repository</name>
<url>http://maven-repo.evolvis.org/releases</url>
<snapshots>
<enabled>false</enabled>
</snapshots>
- </pluginRepository>
+ </pluginRepository-->
</pluginRepositories>
<!--Tracking-->
@@ -245,6 +245,7 @@
<module>simexplorer-is-service</module>
<module>simexplorer-is-web</module>
<module>simexplorer-is-swing-jaxx</module>
+ <module>simexplorer-is-swing-commandline</module>
<module>simexplorer-is-swing</module>
<module>simexplorer-is-ear</module>
</modules>
Modified: trunk/simexplorer-is/simexplorer-is-swing/dev.sh
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/dev.sh 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/dev.sh 2008-03-16 11:44:47 UTC (rev 1364)
@@ -79,20 +79,21 @@
###############################################################################
MVN_ACTION=
if [ "$CLEAN" = "clean" ]; then
- MVN_ACTION="clean dependency:copy-dependencies compile"
+ MVN_ACTION="clean compile"
if [ "$DEV" = "jar" ]; then
- MVN_ACTION="$MVN_ACTION jar:jar"
+ MVN_ACTION="$MVN_ACTION package"
fi
else
- if [ ! -d $rep/target/dependency ]; then
- MVN_ACTION="$MVN_ACTION dependency:copy-dependencies"
- fi
+ #if [ ! -d $rep/target/dependency ]; then
+ # MVN_ACTION="$MVN_ACTION dependency:copy-dependencies"
+ #fi
if [ ! -d $rep/target/classes -o "$COMPILE" = "compile" ]; then
- MVN_ACTION="$MVN_ACTION compile"
+ MVN_ACTION="$MVN_ACTION compile "
+ else
+ if [ "$DEV" = "jar" -a ! -f $rep/target/$RELEASE.jar ]; then
+ MVN_ACTION="$MVN_ACTION package"
+ fi
fi
- if [ "$DEV" = "jar" -a ! -f $rep/target/$RELEASE.jar ]; then
- MVN_ACTION="$MVN_ACTION jar:jar"
- fi
fi
###############################################################################
Modified: trunk/simexplorer-is/simexplorer-is-swing/pom.xml
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/pom.xml 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/pom.xml 2008-03-16 11:44:47 UTC (rev 1364)
@@ -26,12 +26,6 @@
</activation>
<properties>
<maven.verbose>false</maven.verbose>
- <!-- Vcs base dir-->
- <maven.vcs.src.dir>${basedir}/src</maven.vcs.src.dir>
- <!--Source base dir-->
- <maven.src.dir>${basedir}/target/src-build</maven.src.dir>
- <!--Generate base dir-->
- <maven.gen.dir>${basedir}/target/gen</maven.gen.dir>
<!--Main class in JAR -->
<maven.jar.main.class>fr.cemagref.simexplorer.is.ui.swing.SimExplorer</maven.jar.main.class>
</properties>
@@ -40,60 +34,6 @@
<build>
<plugins>
- <!-- Generate phase -->
- <plugin>
- <artifactId>maven-antrun-plugin</artifactId>
- <configuration>
- <!-- recopie des fichiers java sources et generes vers src-build/java -->
- <tasks>
- <copy todir="${maven.src.dir}/java" verbose="${maven.verbose}" overwrite="true">
- <fileset dir="${maven.gen.dir}/java"/>
- </copy>
- <copy todir="${maven.src.dir}/java" verbose="${maven.verbose}" overwrite="true">
- <fileset dir="${maven.vcs.src.dir}/java"/>
- </copy>
- </tasks>
- </configuration>
- <executions>
- <execution>
- <phase>generate-sources</phase>
- <goals>
- <goal>run</goal>
- </goals>
- </execution>
- </executions>
- </plugin>
- <plugin>
- <groupId>lutinplugin</groupId>
- <artifactId>maven-commandline-plugin</artifactId>
- <version>0.3</version>
- <configuration>
- <prefix>SimExplorer</prefix>
- <i18nPrefix>simexplorer</i18nPrefix>
- <source>${maven.vcs.src.dir}/resources/commandline.properties</source>
- <parserPackageName>fr.cemagref.simexplorer.is.ui.swing.commandline</parserPackageName>
- <abstractConfigOptionKey>CONFIG_OPTION_KEY</abstractConfigOptionKey>
- <abstractConfigFileOptionKey>CONFIG_FILE_OPTION_KEY</abstractConfigFileOptionKey>
- <abstractConfigFilenameConfigKey>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigMain.CONFIG_FILE_NAME_PROPERTY_KEY</abstractConfigFilenameConfigKey>
- <concreteConfig>true</concreteConfig>
- <actionImplementations>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.actions.SimExplorerCommonActions</value>
- </actionImplementations>
- <configImplementations>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigMain</value>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigLocal</value>
- <value>fr.cemagref.simexplorer.is.ui.swing.commandline.configs.SimExplorerConfigRemote</value>
- </configImplementations>
- </configuration>
- <executions>
- <execution>
- <goals>
- <goal>genJava</goal>
- </goals>
- </execution>
- </executions>
-
- </plugin>
<!-- Compile phase -->
<plugin>
<groupId>lutinplugin</groupId>
@@ -116,7 +56,7 @@
<treateDefaultEntry>false</treateDefaultEntry>
<entries>
<entry>
- <basedir>${maven.vcs.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/actions</basedir>
+ <basedir>${maven.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/actions</basedir>
<includes>
<param>**\/*Action.java</param>
</includes>
@@ -125,7 +65,7 @@
</excludes>
</entry>
<entry>
- <basedir>${maven.vcs.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/ui</basedir>
+ <basedir>${maven.src.dir}/java/fr/cemagref/simexplorer/is/ui/swing/ui</basedir>
<includes>
<param>SimExplorerTab.java</param>
</includes>
@@ -140,18 +80,6 @@
<goal>parserJava</goal>
<goal>gen</goal>
</goals>
- <configuration>
- <entries>
- <entry>
- <specificGoal>parserJava</specificGoal>
- <basedir>${maven.gen.dir}/java/fr/cemagref/simexplorer/is/ui/swing/commandline</basedir>
- <includes>
- <param>**\/*Option*.java</param>
- <param>**\/*Config*.java</param>
- </includes>
- </entry>
- </entries>
- </configuration>
</execution>
</executions>
</plugin>
@@ -202,12 +130,17 @@
<groupId>simexplorer-is</groupId>
<artifactId>simexplorer-is-swing-jaxx</artifactId>
<version>0.1-SNAPSHOT</version>
- </dependency>
- <!-- librairie commandline -->
+ </dependency>
<dependency>
- <groupId>lutinlib</groupId>
- <artifactId>lutincommandline</artifactId>
+ <groupId>simexplorer-is</groupId>
+ <artifactId>simexplorer-is-swing-commandline</artifactId>
<version>0.1-SNAPSHOT</version>
+ </dependency>
+ <!-- librairie commandline-ui -->
+ <dependency>
+ <groupId>lutinlib</groupId>
+ <artifactId>lutincommandline-ui</artifactId>
+ <version>0.2</version>
<scope>compile</scope>
</dependency>
<!-- pour avoir les ejb jboss -->
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorer.java 2008-03-16 11:44:47 UTC (rev 1364)
@@ -24,9 +24,13 @@
import fr.cemagref.simexplorer.is.ui.swing.ui.SimExplorerMainUI;
import fr.cemagref.simexplorer.is.ui.swing.ui.SimExplorerTab;
import fr.cemagref.simexplorer.is.ui.swing.ui.util.ErrorDialog;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
import org.codelutin.i18n.I18n;
+import org.codelutin.option.ParserFailedException;
import java.awt.event.ActionEvent;
+import java.io.IOException;
/**
* L'application principale
@@ -35,6 +39,8 @@
*/
public class SimExplorer {
+ private static final Log log = LogFactory.getLog(SimExplorer.class);
+
/** le context principal de l'application */
protected static SimExplorerContext context;
@@ -50,13 +56,27 @@
* chargement du context
*
* @param args les arguments passés à l'application
- * @throws java.io.IOException si pb pendant l'init
*/
- public static void init(String... args) throws Exception {
+ public static void init(String... args) {
- // init context, parser and configs
- context = new SimExplorerContext(args);
+ try {
+ // init context, parser and configs
+ context = new SimExplorerContext(args);
+ } catch (IOException e) {
+ log.error("io error : " + e.getMessage());
+ e.printStackTrace();
+ System.exit(1);
+ } catch (ParserFailedException e) {
+ log.error("parser error : " + e.getMessage());
+ e.printStackTrace();
+ System.exit(1);
+ } catch (Exception e) {
+ log.error("fatal error : " + e.getMessage());
+ e.printStackTrace();
+ System.exit(1);
+ }
+
}
/** Lancement de l'ui après init de l'application. */
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ChangeSizorAction.java 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ChangeSizorAction.java 2008-03-16 11:44:47 UTC (rev 1364)
@@ -20,7 +20,7 @@
import fr.cemagref.simexplorer.is.ui.swing.actions.util.SimExplorerAbstractTabAction;
import fr.cemagref.simexplorer.is.ui.swing.model.tab.ListTabModel;
-import jaxx.util.SimplePaginationEnum;
+import org.codelutin.util.SimplePaginationEnum;
import javax.swing.Action;
import javax.swing.JComboBox;
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/model/tab/ListTabModel.java 2008-03-16 11:44:47 UTC (rev 1364)
@@ -21,7 +21,7 @@
import fr.cemagref.simexplorer.is.entities.metadata.MetaData;
import fr.cemagref.simexplorer.is.storage.SortColumn;
import fr.cemagref.simexplorer.is.ui.swing.SimExplorerContext;
-import jaxx.util.SimplePaginationEnum;
+import org.codelutin.util.SimplePaginationEnum;
import java.io.Serializable;
Deleted: trunk/simexplorer-is/simexplorer-is-swing/src/resources/commandline.properties
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/resources/commandline.properties 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/resources/commandline.properties 2008-03-16 11:44:47 UTC (rev 1364)
@@ -1,112 +0,0 @@
-###############################################################################
-### Option definitions ########################################################
-###############################################################################
-
-###
-### common options (TODO should be in commandline project)
-###
-showConfig.option.definition=--show-config {0,1} <main|local|remote> [all|tec]
-editConfig.option.definition=--edit-config
-configFile.option.definition=--config-file <configFile:File>
-config.option.definition=--config * [main|local|remote] <key:String> <value:String>
-help.option.definition=--help|-h
-resetConfig.option.definition=--resetConfig
-ui.option.definition=--ui <value:Boolean>
-
-###
-### others options TODO
-###
-
-###############################################################################
-### Local configuration definition ############################################
-###############################################################################
-
-local.config.definition.db=java.io.File:/var/local/simexplorer/local-db
-local.config.modifiers.db=mandatory
-
-local.config.definition.optimizePeriod=java.lang.Integer:3600
-local.config.modifiers.optimizePeriod=mandatory
-
-local.config.definition.data=java.io.File:/var/local/simexplorer/local-data
-local.config.modifiers.data=mandatory
-
-###############################################################################
-### Remote configuration definition ###########################################
-###############################################################################
-
-remote.config.definition.login=java.lang.String
-remote.config.modifiers.login=mandatory
-
-remote.config.definition.password=java.lang.String
-remote.config.modifiers.password=
-
-remote.config.definition.URI=java.net.URI:jnp://localhost:1099
-remote.config.modifiers.URI=static,mandatory
-
-remote.config.definition.useProxy=java.lang.Boolean:False
-remote.config.modifiers.useProxy=
-
-remote.config.definition.useAuthenticationProxy=java.lang.Boolean:False
-remote.config.modifiers.useAuthenticationProxy=
-
-remote.config.definition.proxyLogin=java.lang.String
-remote.config.modifiers.proxyLogin=
-
-remote.config.definition.proxyPassword=java.lang.String
-remote.config.modifiers.proxyPassword=
-
-###############################################################################
-### Main configuration definition #############################################
-###############################################################################
-
-###
-### Application global properties
-###
-main.config.definition.configFileName=java.io.File:.simexplorer-si-1
-main.config.modifiers.configFileName=final,mandatory,transient
-
-main.config.definition.debugMode=java.lang.Boolean:false
-main.config.modifiers.debugMode=mandatory
-
-main.config.definition.version=org.codelutin.util.VersionNumber:0.0.1
-main.config.modifiers.version=final,static,mandatory
-
-main.config.definition.siteURL=java.net.URL:http://simexplorer-si.labs.libre-entreprise.org
-main.config.modifiers.siteURL=final,static,mandatory
-
-#main.config.definition.smtpServer=java.lang.String:smtp
-#main.config.modifiers.smtpServer=mandatory
-
-###
-### Application preferences
-###
-main.config.definition.localSizor=jaxx.util.SimplePaginationEnum:_5
-main.config.modifiers.localSizor=
-
-main.config.definition.remoteSizor=jaxx.util.SimplePaginationEnum:_20
-main.config.modifiers.remoteSizor=
-
-main.config.definition.showLocalTab=java.lang.Boolean:True
-main.config.modifiers.showLocalTab=
-
-main.config.definition.showRemoteTab=java.lang.Boolean:False
-main.config.modifiers.showRemoteTab=
-
-main.config.definition.autoConnect=java.lang.Boolean:False
-main.config.modifiers.autoConnect=
-
-###
-### user properties
-###
-
-main.config.definition.userFirstName=java.lang.String
-main.config.modifiers.userFirstName=mandatory
-
-main.config.definition.userLocale=org.codelutin.i18n.LocaleEnum:fr
-main.config.modifiers.userLocale=mandatory
-
-main.config.definition.userLastName=java.lang.String
-main.config.modifiers.userLastName=mandatory
-
-main.config.definition.userMail=java.lang.String
-main.config.modifiers.userMail=mandatory
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-en_GB.properties
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-en_GB.properties 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-en_GB.properties 2008-03-16 11:44:47 UTC (rev 1364)
@@ -136,48 +136,14 @@
simexplorer.common.name=name
simexplorer.common.value=value
simexplorer.common.version=version
-simexplorer.config.local.data.description=Local database data directory
-simexplorer.config.local.db.description=Local database directory
-simexplorer.config.local.description=Local server configuration
-simexplorer.config.local.optimizePeriod.description=Optimize period (Lucene)
-simexplorer.config.main.autoConnect.description=Flag to auto connect to remote server at init time
-simexplorer.config.main.configFileName.description=The path of the configuration file
-simexplorer.config.main.debugMode.description=Debug mode
-simexplorer.config.main.description=Configuration de l'application SimExplorer SI
-simexplorer.config.main.localSizor.description=number of result to display by page in local list
-simexplorer.config.main.remoteSizor.description=number of result to display by page in remote list
-simexplorer.config.main.showLocalTab.description=Show at launch time, the local tab
-simexplorer.config.main.showRemoteTab.description=Show at launch time, the remote tab
-simexplorer.config.main.siteURL.description=Simexplorer-is site URL
-simexplorer.config.main.userFirstName.description=User first name
-simexplorer.config.main.userLastName.description=User last name
-simexplorer.config.main.userLocale.description=User locale
-simexplorer.config.main.userMail.description=User email adress
-simexplorer.config.main.version.description=Version of application
-simexplorer.config.remote.URI.description=URI of the remote storage service
-simexplorer.config.remote.description=Remote server configuration
-simexplorer.config.remote.login.description=User login to remote server
-simexplorer.config.remote.password.description=User password to connect remote server
-simexplorer.config.remote.proxyLogin.description=login to proxy host
-simexplorer.config.remote.proxyPassword.description=password to proxy host
-simexplorer.config.remote.useAuthenticationProxy.description=use an anthenticated proxy
-simexplorer.config.remote.useProxy.description=use a proxy host toreach remote server
simexplorer.confirm.changeLanguage=Changing to language ''{0}'' will reset the ui and the history
simexplorer.confirm.delete=Confirm delete of ''{0}''
simexplorer.error.login.failed=Remote authentication failed...
simexplorer.error.service.failed=Remote server is not reachable...
simexplorer.login.retry=Do you want to retry ?
-simexplorer.message.reset.user.configuration=
simexplorer.node.descriptors=Descriptor(s) ({0})
simexplorer.node.noattachments=No attachment
simexplorer.node.nodetail=No detail
-simexplorer.option.description.config=change value of configuration property (with **key**) by value **value**.
-simexplorer.option.description.configFile=configuration's file
-simexplorer.option.description.editConfig=to launch UI of configuration modifier
-simexplorer.option.description.help=Show this help
-simexplorer.option.description.resetConfig=Reset user configuration.
-simexplorer.option.description.showConfig=See configuration details
-simexplorer.option.description.ui=launch or not user interface (value)
simexplorer.tab.detail=Detail
simexplorer.tab.detail.tooltip=Screen of details of an element
simexplorer.tab.local=Local elements
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-fr_FR.properties
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-fr_FR.properties 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/resources/i18n/simexplorer-is-swing-fr_FR.properties 2008-03-16 11:44:47 UTC (rev 1364)
@@ -136,48 +136,14 @@
simexplorer.common.name=nom
simexplorer.common.value=valeur
simexplorer.common.version=version
-simexplorer.config.local.data.description=R\u00E9pertoire des donn\u00E9es de la base locale
-simexplorer.config.local.db.description=R\u00E9pertoire de la base locale
-simexplorer.config.local.description=Configuration du serveur local
-simexplorer.config.local.optimizePeriod.description=La p\u00E9riode optimale (Lucene)
-simexplorer.config.main.autoConnect.description=Se connecter automatiquement au d\u00E9marrage
-simexplorer.config.main.configFileName.description=Le chemin du fichier de configuration
-simexplorer.config.main.debugMode.description=Mode debug
-simexplorer.config.main.description=La configuration de l'application
-simexplorer.config.main.localSizor.description=Nombre de r\u00E9sultats par page dans la liste locale
-simexplorer.config.main.remoteSizor.description=Nombre de r\u00E9sultats par page dans la liste distante
-simexplorer.config.main.showLocalTab.description=Voir au d\u00E9marrage l'onglet Local
-simexplorer.config.main.showRemoteTab.description=Voir au d\u00E9mrrage l'onglet Distant
-simexplorer.config.main.siteURL.description=L'URL du site de Simexplorer-is
-simexplorer.config.main.userFirstName.description=Le pr\u00E9nom de l'utilisateur
-simexplorer.config.main.userLastName.description=Le nom de l'utilisateur
-simexplorer.config.main.userLocale.description=La langue de l'utilisateur
-simexplorer.config.main.userMail.description=Le courriel de l'utilisateur
-simexplorer.config.main.version.description=La version du logiciel
-simexplorer.config.remote.URI.description=l'uri du service distant
-simexplorer.config.remote.description=Configuration du serveur distant
-simexplorer.config.remote.login.description=Le login de l'utilisateur au service distant
-simexplorer.config.remote.password.description=Le mot de passe utilisateur (non visible) au serveur distant
-simexplorer.config.remote.proxyLogin.description=Login proxy
-simexplorer.config.remote.proxyPassword.description=Mot de passe proxy
-simexplorer.config.remote.useAuthenticationProxy.description=utilise une authentification sur le proxy
-simexplorer.config.remote.useProxy.description=utilise un proxy pour atteindre le serveur distant
simexplorer.confirm.changeLanguage=Changer vers la langue ''{0}'' va r\u00E9initialiser les interfaces et l''historique
simexplorer.confirm.delete=Confirmer la suppression de ''{0}''
simexplorer.error.login.failed=L'authentification a \u00E9chou\u00E9e...
simexplorer.error.service.failed=Le serveur central n'est pas joignable
simexplorer.login.retry=Voulez-vous ressayer de vous connecter ?
-simexplorer.message.reset.user.configuration=
simexplorer.node.descriptors=Descripteur(s) ({0})
simexplorer.node.noattachments=Pas de fichier attach\u00E9
simexplorer.node.nodetail=Pas de d\u00E9tail
-simexplorer.option.description.config=remplace la valeur d'une propri\u00E9t\u00E9 de clef **key** de la configuration par la valeur **value**.
-simexplorer.option.description.configFile=le fichier de configuration utilis\u00E9
-simexplorer.option.description.editConfig=pour lancer l'UI d'\u00E9dition de la configuration
-simexplorer.option.description.help=Show this help
-simexplorer.option.description.resetConfig=R\u00E9initialisation de la configuration.
-simexplorer.option.description.showConfig=Voir les d\u00E9tails d'une configuration
-simexplorer.option.description.ui=launch or not user interface (value)
simexplorer.tab.detail=D\u00E9tail
simexplorer.tab.detail.tooltip=L'\u00E9cran affichant les d\u00E9tails d'un \u00E9l\u00E9ment
simexplorer.tab.local=Liste locale
Copied: trunk/simexplorer-is/simexplorer-is-swing-commandline (from rev 1363, branches/20080315_before_commandline_split/simexplorer-is/simexplorer-is-swing-commandline)
Property changes on: trunk/simexplorer-is/simexplorer-is-swing-commandline
___________________________________________________________________
Name: svn:ignore
+ *.iml
.project
.classpath
target
Modified: trunk/simexplorer-is/simexplorer-is-swing-jaxx/pom.xml
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing-jaxx/pom.xml 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing-jaxx/pom.xml 2008-03-16 11:44:47 UTC (rev 1364)
@@ -1,8 +1,8 @@
<?xml version="1.0" encoding="UTF-8"?>
<project xmlns="http://maven.apache.org/POM/4.0.0"
- xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
-
+ xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+ xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
+
<modelVersion>4.0.0</modelVersion>
<artifactId>simexplorer-is-swing-jaxx</artifactId>
@@ -18,37 +18,58 @@
<version>0.1-SNAPSHOT</version>
</parent>
- <profiles>
- <profile>
- <id>project</id>
- <activation>
- <activeByDefault>true</activeByDefault>
- </activation>
- <properties>
- <maven.verbose>false</maven.verbose>
- </properties>
- </profile>
- </profiles>
-
+ <profiles>
+ <profile>
+ <id>project</id>
+ <activation>
+ <activeByDefault>true</activeByDefault>
+ </activation>
+ <properties>
+ <maven.verbose>false</maven.verbose>
+ <maven.java.src.dir>${maven.src.dir}/java</maven.java.src.dir>
+ </properties>
+ </profile>
+ </profiles>
+
<build>
<plugins>
+ <plugin>
+ <!--- Clean phase : we must clean also src/java files -->
+ <artifactId>maven-antrun-plugin</artifactId>
+ <executions>
+ <execution>
+ <phase>clean</phase>
+ <configuration>
+ <tasks>
+ <delete includeemptydirs="true">
+ <fileset dir="${maven.java.src.dir}" includes="**/*"/>
+ </delete>
+ </tasks>
+ </configuration>
+ <goals>
+ <goal>run</goal>
+ </goals>
+ </execution>
+ </executions>
+ </plugin>
+
<!-- Generate phase : this is a fully generated module
- At checkout, there is no source java files, and the
- ${maven.src.dir}/java directory is svn ignored.
+ At checkout, there is no source java files, and the
+ ${maven.src.dir}/java directory is svn ignored.
- The jaxx generator will generate java source files in this
- directory, after this, maven compiles as normal and use an unique
- source directory, with no trick for generation.
+ The jaxx generator will generate java source files in this
+ directory, after this, maven compiles as normal and use an unique
+ source directory, with no trick for generation.
- We use now a fully compiliance maven process:)
- -->
+ We use now a fully compiliance maven process:)
+ -->
<plugin>
<groupId>lutinplugin</groupId>
<artifactId>maven-jaxx-plugin</artifactId>
<version>0.2-SNAPSHOT</version>
- <configuration>
- <out>${maven.src.dir}/java</out>
- </configuration>
+ <configuration>
+ <out>${maven.java.src.dir}</out>
+ </configuration>
<executions>
<execution>
<goals>
@@ -73,19 +94,17 @@
<bundles>
<param>fr_FR</param>
<param>en_GB</param>
- </bundles>
+ </bundles>
</configuration>
- <executions>
+ <executions>
<execution>
- <phase>compile</phase>
- <!--id>java</id-->
<goals>
- <goal>parserJaxx</goal>
+ <goal>parserJaxx</goal>
<goal>gen</goal>
- </goals>
+ </goals>
</execution>
</executions>
- </plugin>
+ </plugin>
</plugins>
</build>
@@ -103,6 +122,6 @@
<artifactId>jaxx</artifactId>
<version>1.0.4-SNAPSHOT</version>
<scope>compile</scope>
- </dependency>
+ </dependency>
</dependencies>
</project>
Modified: trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/JListTab.jaxx
===================================================================
--- trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/JListTab.jaxx 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing-jaxx/src/uimodel/fr/cemagref/simexplorer/is/ui/swing/ui/JListTab.jaxx 2008-03-16 11:44:47 UTC (rev 1364)
@@ -27,7 +27,7 @@
<JTextField id='searchText' toolTipText='simexplorer.action.searchText.tooltip'/>
<JButton id='search'/>
<JButton id='advancedSearch'/>
- <org.codelutin.util.EnumEditor id='changeSizor' font-size='9' constructorParams="jaxx.util.SimplePaginationEnum.class" enabled='false' opaque='false' preferredSize='{new Dimension(50,5)}'/>
+ <org.codelutin.util.EnumEditor id='changeSizor' font-size='9' constructorParams="org.codelutin.util.SimplePaginationEnum.class" enabled='false' opaque='false' preferredSize='{new Dimension(50,5)}'/>
</JToolBar>
</cell>
</row>
1
0
--- trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java 2008-03-16 11:18:42 UTC (rev 1363)
+++ trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/SimExplorerContext.java 2008-03-16 11:44:47 UTC (rev 1364)
@@ -33,7 +33,7 @@
import fr.cemagref.simexplorer.is.storage.SortColumn;
import fr.cemagref.simexplorer.is.ui.swing.commandline.SimExplorerAbstractContext;
import org.codelutin.i18n.I18n;
-import org.codelutin.option.ParserException;
+import org.codelutin.option.ParserFailedException;
import java.io.IOException;
@@ -181,11 +181,10 @@
* restricted access constructor
*
* @param args argumentsfor parser
* @throws java.io.IOException if pb while saing configuration
* @throws org.codelutin.option.ParserException
* if pb while parsing arguments
*/
- SimExplorerContext(String... args) throws IOException, ParserException {
+ SimExplorerContext(String... args) throws IOException, ParserFailedException {
super(args);
Modified: trunk/simexplorer-is/simexplorer-is-swing/src/java/fr/cemagref/simexplorer/is/ui/swing/actions/ChangeSizorAction.java
===================================================================
@@ -181,11 +181,10 @@
*
* @param args argumentsfor parser
- * @throws java.io.IOException if pb while saing configuration
- * @throws org.codelutin.option.ParserException
- * if pb while parsing arguments
+ * @throws java.io.IOException if pb while saing configuration
+ * @throws ParserFailedException if pb while parsing arguments
*/